@@ -312,6 +312,19 @@ func Test_NamespacesForLanguage(t *testing.T) {
 				"a-name",
 			},
 		},
+		{
+			language: syftPkg.Dotnet,
+			namerInput: &pkg.Package{
+				ID:   pkg.ID(uuid.NewString()),
+				Name: "a-name",
+			},
+			expectedNamespaces: []string{
+				"github:nuget",
+			},
+			expectedNames: []string{
+				"a-name",
+			},
+		},
 	}
 
 	observedLanguages := strset.New()
