@@ -9,6 +9,7 @@ const (
 	RpmDBMatcher       MatcherType = "rpmdb-matcher"
 	JavaMatcher        MatcherType = "java-matcher"
 	PythonMatcher      MatcherType = "python-matcher"
+	DotnetMatcher      MatcherType = "dotnet-matcher"
 	JavascriptMatcher  MatcherType = "javascript-matcher"
 	MsrcMatcher        MatcherType = "msrc-matcher"
 )
@@ -20,6 +21,7 @@ var AllMatcherTypes = []MatcherType{
 	RpmDBMatcher,
 	JavaMatcher,
 	PythonMatcher,
+	DotnetMatcher,
 	JavascriptMatcher,
 	MsrcMatcher,
 }
