@@ -62,7 +62,7 @@ func NewVulnerability(vuln grypeDB.Vulnerability) (*Vulnerability, error) {
 }
 
 func (v Vulnerability) String() string {
-	return fmt.Sprintf("Vuln(id=%s constraint='%s')", v.ID, v.Constraint)
+	return fmt.Sprintf("Vuln(id=%s constraint=%q)", v.ID, v.Constraint.String())
 }
 
 func (v *Vulnerability) hash() string {
